Implementation of the defrule-style DSL for Concrete Rules. Most users should simply use the metasimple.concrete.rules namespace.
Implementation of the defrule-style DSL for Concrete Rules. Most users should simply use the metasimple.concrete.rules namespace.
(build-query name body)(build-query name body form-meta)Function used to parse and build a query using the DSL syntax.
Function used to parse and build a query using the DSL syntax.
(build-rule name body)(build-rule name body form-meta)Function used to parse and build a rule using the DSL syntax.
Function used to parse and build a rule using the DSL syntax.
(parse-query params lhs)Macro used to dynamically create a new rule using the DSL syntax.
Macro used to dynamically create a new rule using the DSL syntax.
(parse-query* params lhs env)(parse-query* params lhs env query-meta)Creates a query from the DSL syntax using the given environment map.
Creates a query from the DSL syntax using the given environment map.
(parse-rule lhs rhs)(parse-rule lhs rhs properties)Macro used to dynamically create a new rule using the DSL syntax.
Macro used to dynamically create a new rule using the DSL syntax.
(parse-rule* lhs rhs properties env)(parse-rule* lhs rhs properties env rule-meta)Creates a rule from the DSL syntax using the given environment map. ns should be bound to the namespace the rule is meant to be defined in.
Creates a rule from the DSL syntax using the given environment map. *ns* should be bound to the namespace the rule is meant to be defined in.
(split-lhs-rhs rule-body)Given a rule with the =>, splits the left- and right-hand sides.
Given a rule with the =>, splits the left- and right-hand sides.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |