Forward-chaining rules for Clojure. The primary API is in this namespace.
Forward-chaining rules for Clojure. The primary API is in this namespace.
A set of common accumulators usable in Concrete Rules rules.
A set of common accumulators usable in Concrete Rules rules.
This namespace is for internal use and may move in the future. This is the Concrete Rules rules compiler, translating raw data structures into compiled versions and functions. Most users should use only the metasimple.concrete.rules namespace.
This namespace is for internal use and may move in the future. This is the Concrete Rules rules compiler, translating raw data structures into compiled versions and functions. Most users should use only the metasimple.concrete.rules namespace.
Implementation of the defrule-style DSL for Concrete Rules. Most users should simply use the metasimple.concrete.rules namespace.
Implementation of the defrule-style DSL for Concrete Rules. Most users should simply use the metasimple.concrete.rules namespace.
Support for persisting Concrete Rules sessions to an external store. Provides the ability to store and restore an entire session working memory state. The restored session is able to have additional insert, retract, query, and fire rule calls performed immediately after.
See https://github.com/cerner/clara-rules/issues/198 for more discussion on this.
Note! This is still an EXPERIMENTAL namespace. This may change non-passively without warning. Any session or rulebase serialized in one version of Concrete Rules is not guaranteed to deserialize successfully against another version of Concrete Rules.
Support for persisting Concrete Rules sessions to an external store. Provides the ability to store and restore an entire session working memory state. The restored session is able to have additional insert, retract, query, and fire rule calls performed immediately after. See https://github.com/cerner/clara-rules/issues/198 for more discussion on this. Note! This is still an EXPERIMENTAL namespace. This may change non-passively without warning. Any session or rulebase serialized in one version of Concrete Rules is not guaranteed to deserialize successfully against another version of Concrete Rules.
A default Fressian-based implementation of d/ISessionSerializer.
Note! Currently this only supports the metasimple.concrete.rules.memory.PersistentLocalMemory implementation of memory.
A default Fressian-based implementation of d/ISessionSerializer.
Note! Currently this only supports the metasimple.concrete.rules.memory.PersistentLocalMemory implementation
of memory.This namespace is for internal use and may move in the future. Most users should use only the metasimple.concrete.rules namespace.
This namespace is for internal use and may move in the future. Most users should use only the metasimple.concrete.rules namespace.
This namespace is for internal use and may move in the future. Java support. Users should use the Java API, or the metasimple.concrete.rules namespace from Clojure.
This namespace is for internal use and may move in the future. Java support. Users should use the Java API, or the metasimple.concrete.rules namespace from Clojure.
Event listeners for analyzing the flow through Concrete Rules. This is for primarily for use by tooling, but advanced users may use this to analyze sessions.
Event listeners for analyzing the flow through Concrete Rules. This is for primarily for use by tooling, but advanced users may use this to analyze sessions.
This namespace is for internal use and may move in the future. Specification and default implementation of working memory
This namespace is for internal use and may move in the future. Specification and default implementation of working memory
This namespace is for internal use and may move in the future.
This namespace is for internal use and may move in the future.
Schema definition of Concrete Rules data structures using Prismatic's Schema library. This includes structures for rules and queries, as well as the schema for the underlying Rete network itself. This can be used by tools or other libraries working with rules.
Schema definition of Concrete Rules data structures using Prismatic's Schema library. This includes structures for rules and queries, as well as the schema for the underlying Rete network itself. This can be used by tools or other libraries working with rules.
This namespace exists primary for testing purposes, working around the fact that we cannot AOT compile test classes. This should be moved to the tests once a workaround for this is solved.
This namespace exists primary for testing purposes, working around the fact that we cannot AOT compile test classes. This should be moved to the tests once a workaround for this is solved.
No vars found in this namespace.
Tooling to inspect a rule session. The two major methods here are:
Tooling to inspect a rule session. The two major methods here are: * inspect, which returns a data structure describing the session that can be used by tooling. * explain-activations, which uses inspect and prints a human-readable description covering why each rule activation or query match occurred.
Internal implementation details of session inspection. Nothing in this namespace should be directly referenced by callers outside of the concrete-rules project.
Internal implementation details of session inspection. Nothing in this namespace should be directly referenced by callers outside of the concrete-rules project.
Internal utilities for testing concrete-rules and derivative projects. These should be considered experimental right now from the perspective of consumers of concrete-rules, although it is possible that this namespace will be made part of the public API once its functionality has proven robust and reliable. The focus, however, is functionality needed to test the rules engine itself.
Internal utilities for testing concrete-rules and derivative projects. These should be considered experimental right now from the perspective of consumers of concrete-rules, although it is possible that this namespace will be made part of the public API once its functionality has proven robust and reliable. The focus, however, is functionality needed to test the rules engine itself.
Support for tracing state changes in a Concrete Rules session.
Support for tracing state changes in a Concrete Rules session.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |